<?PHP
/* Copyright (C) 2004-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: compta.export.class.php,v 1.11 2005/07/10 20:26:11 eldy Exp $
 * $Source: /cvsroot/dolibarr/dolibarr/htdocs/compta/export/modules/compta.export.class.php,v $
 */

/**
        \file       htdocs/compta/export/modules/compta.export.class.php
        \ingroup    compta
        \brief      Fichier de la classe d'export compta
        \version    $Revision: 1.11 $
*/


/**
        \class      ComptaExport
        \brief      Classe permettant les exports comptables
*/

class ComptaExport
{

  /**
        \brief      Constructeur de la class
        \param      DB          Object de base de donnes
        \param      USER        Object utilisateur    
        \param      classe      Nom de la classe utilise pour formater les rapports
  */
  function ComptaExport ($DB, $USER, $classe)
  {
    $this->db = $DB;
    $this->user = $USER;
    $this->classe_export = $classe;
    $this->error_message = '';
  }


  /**
        \brief      Lecture des factures dans la base
        \param      id      Id ligne
  */
  function ReadLines($id=0)
  {
    dolibarr_syslog("ComptaExport::ReadLines id=".$id);

    $error = 0;

    $sql = "SELECT f.num_piece, f.date_piece";
    $sql .= " , f.journal, l.num_ligne ";
    $sql .= " ,c.numero as numero_compte";
    $sql .= " , l.sens, l.montant as montant_ligne, l.libelle";
    $sql .= " , l.id_piece";
    $sql .= " FROM ".MAIN_DB_PREFIX."compta_lignes as l";
    $sql .= " , ".MAIN_DB_PREFIX."compta_pieces as f";
    $sql .= " , ".MAIN_DB_PREFIX."compta_compte_generaux as c";
    
    $sql .= " WHERE f.rowid = l.id_piece ";
	$sql .= " AND l.compte = c.rowid ";
	$sql .= " AND f.exportee = ".$id;

    $sql .= " ORDER BY l.journal, l.num_piece ASC, l.num_ligne ASC";

    $resql = $this->db->query($sql);

    if ($resql)
      {
	$num = $this->db->num_rows($resql);
	$i = 0;
	$this->linec = array();

	while ($i < $num)
	  {
	    $obj = $this->db->fetch_object($resql);

	    $this->linec[$i][0] = $obj->date_piece;
	    $this->linec[$i][1] = $obj->journal;
	    $this->linec[$i][2] = $obj->num_piece;
	    $this->linec[$i][3] = $obj->num_ligne;
	    $this->linec[$i][4] = $obj->numero_compte;
	    $this->linec[$i][5] = $obj->libelle;
	    $this->linec[$i][6] = $obj->sens;
	    $this->linec[$i][7] = $obj->montant_ligne;
		$this->linec[$i][8] = $obj->id_piece;
	    
	    $i++;
	  }
	$this->db->free($resql);
      }    

    return $error;
  }

  
  /**
    \brief      Cr le fichier d'export
  */

  function Export($id=0)
  {
    $error = 0;

    dolibarr_syslog("ComptaExport::Export");

    $error += $this->ReadLines($id);
    
    dolibarr_syslog("ComptaExport::Export Pieces : ".sizeof($this->linec));

    if (!$error && (sizeof($this->linec) > 0))
      {
	include_once DOL_DOCUMENT_ROOT.'/compta/export/modules/compta.export.'.strtolower($this->classe_export).'.class.php';  

	$objexport_name = "ComptaExport".$this->classe_export;

	$objexport = new $objexport_name($this->db, $this->user);

	$objexport->Export($this->linec, $id);

	$this->id = $objexport->id;
	$this->ref = $objexport->ref;
      }
  }

}
