<?php
/* Copyright (C) 2005 Laurent Destailleur  <eldy@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: interface_demo.class.php,v 1.7 2005/12/10 13:56:05 eldy Exp $
 * $Source: /cvsroot/dolibarr/dolibarr/htdocs/includes/triggers/interface_demo.class.php,v $
 */

/**
        \file       htdocs/includes/triggers/interface_demo.class.php
        \ingroup    core
        \brief      Fichier de demo de personalisation des actions du workflow
        \remarks    Son propre fichier d'actions peut etre cr par recopie de celui-ci:
                    - Le nom du fichier doit etre interface_xxx.class.php
                    - Le fichier doit rester stock dans includes/triggers
                    - Le nom de la classe doit etre InterfaceXxx
*/


/**
        \class      InterfaceCompta
        \brief      Classe des fonctions triggers des actions personalises du workflow
*/

class InterfaceCompta
{
    private $db;
    
    /**
     *   \brief      Constructeur.
     *   \param      DB      Handler d'accs base
     */
    public function InterfaceCompta($DB)
    {
        $this->db = $DB ;
    
        $this->name = "altacompta";
        $this->family = "altairis GPL product";
        $this->description = "Interface Dolibarr/compta";
        $this->version = 'altacompta 1.0';                        // 'experimental' or 'dolibarr' or version
    }
    
    /**
     *   \brief      Renvoi nom du lot de triggers
     *   \return     string      Nom du lot de triggers
     */
    function getName()
    {
        return $this->name;
    }
    
    /**
     *   \brief      Renvoi descriptif du lot de triggers
     *   \return     string      Descriptif du lot de triggers
     */
    function getDesc()
    {
        return $this->description;
    }

    /**
     *   \brief      Renvoi version du lot de triggers
     *   \return     string      Version du lot de triggers
     */
    function getVersion()
    {
        global $langs;
        $langs->load("admin");

        if ($this->version == 'experimental') return $langs->trans("Experimental");
        elseif ($this->version == 'dolibarr') return DOL_VERSION;
        elseif ($this->version) return $this->version;
        else return $langs->trans("Unknown");
    }
	
/**
     *      \brief      Fonction appele lors du dclenchement d'un vnement Dolibarr.
     *                  D'autres fonctions run_trigger peuvent etre prsentes dans includes/triggers
     *      \param      action      Code de l'evenement
     *      \param      object      Objet concern
     *      \param      user        Objet user
     *      \param      lang        Objet lang
     *      \param      conf        Objet conf
     *      \return     int         <0 si ko, 0 si aucune action faite, >0 si ok
     */
	function run_trigger($action,$object,$user,$langs,$conf)
    {
	    // Mettre ici le code  excuter en raction de l'action
        // Les donnes de l'action sont stockes dans $object
    
        // Users
        if     ($action == 'USER_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        elseif ($action == 'USER_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        elseif ($action == 'USER_DISABLE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        // Companies
        elseif     ($action == 'COMPANY_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        elseif ($action == 'COMPANY_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        elseif ($action == 'COMPANY_DELETE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched. id=".$object->id);
        }
        // Proposals
        elseif ($action == 'PROPAL_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PROPAL_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PROPAL_VALIDATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PROPAL_CLOSE_SIGNED')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PROPAL_CLOSE_REFUSED')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        // Contracts
        elseif ($action == 'CONTRACT_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'CONTRACT_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'CONTRACT_ACTIVATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'CONTRACT_CANCEL')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'CONTRACT_CLOSE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'CONTRACT_DELETE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        // Bills
        elseif ($action == 'BILL_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'BILL_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'BILL_VALIDATE')
        {
	        $this->interface_facture($action,$object,$user,$langs,$conf);
	    }
        elseif ($action == 'BILL_CANCEL')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'BILL_DELETE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        // Paiements
		elseif ($action == 'PAIEMENT_VALIDATE')
        {
            $this->interface_reglement($action,$object,$user,$langs,$conf);

        }
        // Products
        elseif ($action == 'PRODUCT_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PRODUCT_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'PRODUCT_DELETE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'ORDER_CREATE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'ORDER_MODIFY')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'ORDER_DELETE')
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' launched");
        }
        elseif ($action == 'FOURN_BILL_VALIDATE')
        {
	        $this->interface_facture_fournisseur($action,$object,$user,$langs,$conf);
	    }
        elseif ($action == 'FOURN_PAIEMENT_VALIDATE')
        {
            $this->interface_reglement_fournisseur($action,$object,$user,$langs,$conf);

        }
        else
        {
            dolibarr_syslog("Trigger '".$this->name."' for action '$action' was ran but no handler found for this action.");
			return -1;
        }
		return 0;
    }

	function interface_reglement($action,$reglement,$user,$langs,$conf)
	{
		include_once(DOL_DOCUMENT_ROOT.'/compta/compta.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/facture.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/compta/bank/account.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/product.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/societe.class.php');
		
		// instanciation des objets
		$piece = new Piece($this->db);
		$ligne = new Ligne($this->db);
		$nat = new Nature($this->db);
		$param = new Param($this->db);
		$tp = new Type_Piece($this->db);
		$prod = new Product($this->db);
		$facture = new Facture($this->db);
		$societe = new Societe($this->db);
		$banque = new Account($this->db);
		$compte = new Compte($this->db);
								
		// recuperation type de piece dans table param
		$type_piece = $param->getValeur('TYPE_PIECE_REGLEMENT_CLIENT');
		// recuperation du journal sur le type de piece
		$journal = $tp->getJournal($type_piece);
		// on met le login de l'utilisateur courant dans le code origine
		$code_origine=$user->login;

		// recuperation des infos du reglement
		$reglement->fetch($reglement->id);
		$date_piece=$reglement->datepaye;
		$mrg=$reglement->mrg;
		
		// recuperation du compte de banque
		$banque->fetch($reglement->bank_account);
		// recuperation du journal sur le compte de treso
		$journal = $compte->getJournal($banque->compte);
				
		// recuperation infos facture d'origine
		$facture->fetch($reglement->facid);
		$reference=$facture->ref;
		
		// recuperation infos tiers
		$societe->fetch($facture->socidp);
		$tiers = $facture->socidp;
		
		$libelle = 'Rglement de la facture '.$facture->ref.' du '.date("d/m/y",$facture->date).'('.$societe->nom.')';
		$montant_ht	= 0;
		$montant_tva = 0;
		
		//insertion piece
		$id_piece=$piece->nouvelle_piece($journal, $date_piece, $reglement->montant, $libelle, $tiers, $code_origine, $reference, $type_piece, $montant_ht, $montant_tva, $mrg);
		if (!$id_piece) {
			return -1;
		}
		else
		{
			$num_piece = $piece->getNumPiece();
			
			// insertion lignes de la piece
			/*	
			* Banque -> debit
			*
			*/
								
			$ligne->nouvelle_ligne($id_piece,
									1,
									$journal,
									$num_piece,
									'',
									$banque->compte,
									$reglement->montant,
									'D',
									$libelle
								);

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
			/*
			 * Client->crdit
			 *
			 */
			$ligne->nouvelle_ligne($id_piece,
									  2,
									  $journal,
									  $num_piece,
									  '',
									  $societe->code_compta,
									  $reglement->montant,
									  'C',
									  $libelle
									  );

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
		}
	}

	function interface_reglement_fournisseur($action,$reglement,$user,$langs,$conf)
	{
		include_once(DOL_DOCUMENT_ROOT.'/compta/compta.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/fourn/fournisseur.facture.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/compta/bank/account.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/product.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/societe.class.php');
		
		// instanciation des objets
		$piece = new Piece($this->db);
		$ligne = new Ligne($this->db);
		$nat = new Nature($this->db);
		$param = new Param($this->db);
		$tp = new Type_Piece($this->db);
		$prod = new Product($this->db);
		$facture = new FactureFournisseur($this->db);
		$societe = new Societe($this->db);
		$banque = new Account($this->db);
		$compte = new Compte($this->db);
								
		// recuperation type de piece dans table param
		$type_piece = $param->getValeur('TYPE_PIECE_PAIEMENT_FOURNISSEUR');
		
		// on met le login de l'utilisateur courant dans le code origine
		$code_origine=$user->login;

		// recuperation des infos du reglement
		$reglement->fetch($reglement->id);
		$date_piece=$reglement->datepaye;
		$mrg=$reglement->mrg;
		
		// recuperation du compte de banque
		$banque->fetch($reglement->bank_account);
		// recuperation du journal sur le compte de treso
		$journal = $compte->getJournal($banque->compte);
				
		// recuperation infos facture d'origine
		$liste_factures_reglees = $reglement->getBillsArray();
		$i = 0;
		$liste_fac = '';
		while ($i < sizeOf($liste_factures_reglees))
		{
			$facture->fetch($liste_factures_reglees[$i]);
			$liste_fac .= $facture->ref.' ';
			$i++;
		}
		
		$reference = 'Rglement factures '.$liste_fac;
		
		// recuperation infos tiers
		$facture->fetch($liste_fac[0]);
		$societe->fetch($facture->socidp);
		$tiers = $facture->socidp;
		
		$libelle = 'Rglement facture '.$liste_fac;;
		$montant_ht	= 0;
		$montant_tva = 0;
		
		//insertion piece
		$id_piece=$piece->nouvelle_piece($journal, $date_piece, $reglement->montant, $libelle, $tiers, $code_origine, $reference, $type_piece, $montant_ht, $montant_tva, $mrg);
		if (!$id_piece) {
			return -1;
		}
		else
		{
			$num_piece = $piece->getNumPiece();
			
			// insertion lignes de la piece
			/*	
			* Banque -> credit
			*
			*/
								
			$ligne->nouvelle_ligne($id_piece,
									1,
									$journal,
									$num_piece,
									'',
									$banque->compte,
									$reglement->montant,
									'C',
									$libelle
								);

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
			/*
			 *Fournisseur : debit
			 *
			 */
			$ligne->nouvelle_ligne($id_piece,
									  2,
									  $journal,
									  $num_piece,
									  '',
									  $societe->code_compta,
									  $reglement->montant,
									  'D',
									  $libelle
									  );

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
		}
	}
	
	function interface_facture($action,$facture,$user,$langs,$conf)
	{
		include_once(DOL_DOCUMENT_ROOT.'/compta/compta.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/facture.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/product.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/societe.class.php');
		
		// instanciation des objets
		$piece = new Piece($this->db);
		$ligne = new Ligne($this->db);
		$nat = new Nature($this->db);
		$param = new Param($this->db);
		$tp = new Type_Piece($this->db);
		$prod = new Product($this->db);
		$societe = new Societe($this->db);
								
		// recuperation type de piece dans table param
		$type_piece = $param->getValeur('TYPE_PIECE_FACTURE');
		// recuperation du journal sur le type de piece
		$journal = $tp->getJournal($type_piece);
		// on met le login de l'utilisateur courant dans le code origine
		$code_origine=$user->login;
		
		// recuperation des infos  de la facture
		$facture->fetch($facture->id);
		// recuperation infos tiers
		$societe->fetch($facture->socidp);
		$tiers = $facture->socidp;
		
		$date_piece=strftime("%y-%m-%d", $facture->date);
		$reference=$facture->ref;
		$libelle = 'Facture '.$facture->ref.' du '.date("d/m/y",$facture->date).'('.$societe->nom.')';
		$montant_ht	= $facture->total_ttc - $facture->total_tva;
		$montant_tva = $facture->total_tva;
		

		//insertion piece

		$id_piece=$piece->nouvelle_piece($journal, $date_piece, $facture->total_ttc, $libelle, $tiers, $code_origine, $reference, $type_piece, $montant_ht, $montant_tva, '');
		if (!$id_piece) {
			return -1;
		}
		else
		{
			$num_piece = $piece->getNumPiece();
			
			// insertion lignes de la piece
			/*
			 * vente -> credit compte de produit (70)
			 *
			 */
			$sql2 = 'SELECT * FROM '.MAIN_DB_PREFIX.'facturedet WHERE fk_facture = '.$facture->id;
			$resql2 = $this->db->query($sql2);
			if ($resql2)
			{
				$num = $this->db->num_rows($resql2);
				$i = 0;
				$num_ligne = 0;
				$type_produit=null;
				while ($i < $num)
				{
					$obj2 = $this->db->fetch_object($resql2);
					$produit = $prod->fetch($obj2->fk_product);
					
					if ($prod->type != $type_produit) {
						if ($i != 0) {
							$num_ligne++;
							if ($type_produit == null) $nature = $param->getValeur('NATURE_PRODUIT_NULL');
							else $nature = $param->getValeur('NATURE_PRODUIT_'.$type_produit);
							$compte = $nat->getCompte($nature);
							$sens_ligne = 'C';
							$montant_ligne = $montant;
							$libelle_ligne = $libelle;
			
							$id_ligne = $ligne->nouvelle_ligne(
									$id_piece,
									$num_ligne,
									$journal,
									$num_piece,
									$nature,
									$compte,
									$montant_ligne,
									$sens_ligne,
									$libelle_ligne
								);
							if (!$id_ligne)
							{
								dolibarr_print_error($this->db);
							}
						}
						
						$montant = 0;
						$type_produit = $prod->type;
					}
					$montant += (($obj2->price * $obj2->qty) * (1 - $facture->remise_percent / 100)); 
					$i++;
				}
				$num_ligne++;
				if ($type_produit == null) $nature = $param->getValeur('NATURE_PRODUIT_NULL');
				else $nature = $param->getValeur('NATURE_PRODUIT_'.$type_produit);
				$compte = $nat->getCompte($nature);
				$sens_ligne = 'C';
				$montant_ligne = $montant;
				$libelle_ligne = $libelle;

				$id_ligne = $ligne->nouvelle_ligne(
						$id_piece,
						$num_ligne,
						$journal,
						$num_piece,
						$nature,
						$compte,
						$montant_ligne,
						$sens_ligne,
						$libelle_ligne
					);
				if (!$id_ligne)
				{
					dolibarr_print_error($this->db);
				}
				
			}
			/*
			 * TVA -> credit compte tva
			 *
			 */
			$num_ligne++;
			$nature = '';
			$compte = $param->getValeur('COMPTE_TVA_COLLECTEE');
			$sens = 'C';
			$montant_ligne = $facture->total_tva;
			$libelle_ligne = $libelle;
			
			$ligne->nouvelle_ligne(
					$id_piece,
					$num_ligne,
					$journal,
					$num_piece,
					$nature,
					$compte,
					$montant_ligne,
					$sens,
					$libelle_ligne
				);

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
			/*
			 * Produits/services -> debit compte client
			 *
			 */
			$num_ligne++;
			$nature = '';
			$compte = $societe->code_compta;
			$sens = 'D';
			$montant_ligne = $facture->total_ttc;
			$libelle_ligne = $libelle;
			
			$ligne->nouvelle_ligne(
					$id_piece,
					$num_ligne,
					$journal,
					$num_piece,
					$nature,
					$compte,
					$montant_ligne,
					$sens,
					$libelle_ligne
				);
			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
		}
	}
	function interface_facture_fournisseur($action,$facture,$user,$langs,$conf)
	{
		include_once(DOL_DOCUMENT_ROOT.'/compta/compta.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/product.class.php');
		include_once(DOL_DOCUMENT_ROOT.'/societe.class.php');
		
		// instanciation des objets
		$piece = new Piece($this->db);
		$ligne = new Ligne($this->db);
		$nat = new Nature($this->db);
		$param = new Param($this->db);
		$tp = new Type_Piece($this->db);
		$prod = new Product($this->db);
		$societe = new Societe($this->db);
								
		// recuperation type de piece dans table param
		$type_piece = $param->getValeur('TYPE_PIECE_FACTURE_FOURNISSEUR');
		// recuperation du journal sur le type de piece
		$journal = $tp->getJournal($type_piece);
		// on met le login de l'utilisateur courant dans le code origine
		$code_origine=$user->login;
		
		// recuperation des infos  de la facture
		$facture->fetch($facture->id);
		// recuperation infos tiers
		$tiers = $facture->socidp;
		// recuperation infos tiers
		$societe->fetch($facture->socidp);
		$code_compta_fournisseur = $societe->code_compta_fournisseur;
		$code_compta = $societe->code_compta;
		
		$date_piece=strftime("%y-%m-%d", $facture->datep);
		$reference=$facture->ref;
		$libelle = 'Facture '.$facture->ref.' du '.date("d/m/y",$facture->datep).'('.$facture->socnom.')';
		$montant_ht	= $facture->total_ttc - $facture->total_tva;
		$montant_tva = $facture->total_tva;
		

		//insertion piece

		$id_piece=$piece->nouvelle_piece($journal, $date_piece, $facture->total_ttc, $libelle, $tiers, $code_origine, $reference, $type_piece, $montant_ht, $montant_tva, '');
		if (!$id_piece) {
			return -1;
		}
		else
		{
			$num_piece = $piece->getNumPiece();
			
			// insertion lignes de la piece
			/*
			 * vente -> debit compte de charge  (60)
			 *
			 */
			$sql2 = 'SELECT * FROM '.MAIN_DB_PREFIX.'facture_fourn_det WHERE fk_facture_fourn = '.$facture->id;
			$resql2 = $this->db->query($sql2);
			if ($resql2)
			{
				$num = $this->db->num_rows($resql2);
				$i = 0;
				$num_ligne = 0;
				$type_produit=null;
				while ($i < $num)
				{
					$obj2 = $this->db->fetch_object($resql2);
					$produit = $prod->fetch($obj2->fk_product);
					
					if ($produit && $prod->type != $type_produit) {
						if ($i != 0) {
							$num_ligne++;
							if ($type_produit == null) 
							{
								$nature = $param->getValeur('NATURE_DEPENSE_PRODUIT_NULL');
								if ($code_compta_fournisseur == null) $compte = $nat->getCompte($nature);
								else $compte = $code_compta_fournisseur;
							}
							else 
							{
								$nature = $param->getValeur('NATURE_DEPENSE_PRODUIT_'.$type_produit);
								$compte = $nat->getCompte($nature);
							}
							$sens_ligne = 'D';
							$montant_ligne = $montant;
							$libelle_ligne = $libelle;
			
							$id_ligne = $ligne->nouvelle_ligne(
									$id_piece,
									$num_ligne,
									$journal,
									$num_piece,
									$nature,
									$compte,
									$montant_ligne,
									$sens_ligne,
									$libelle_ligne
								);
							if (!$id_ligne)
							{
								dolibarr_print_error($this->db);
							}
						}
						
						$montant = 0;
						$type_produit = $prod->type;
					}
					$montant += $obj2->total_ht; 
					$i++;
				}
				$num_ligne++;
				if ($type_produit == null) 
				{
					$nature = $param->getValeur('NATURE_DEPENSE_PRODUIT_NULL');
					if ($code_compta_fournisseur == null) $compte = $nat->getCompte($nature);
					else $compte = $code_compta_fournisseur;
				}
				else 
				{
					$nature = $param->getValeur('NATURE_DEPENSE_PRODUIT_'.$type_produit);
					$compte = $nat->getCompte($nature);
				}
				$sens_ligne = 'D';
				$montant_ligne = $montant;
				$libelle_ligne = $libelle;

				$id_ligne = $ligne->nouvelle_ligne(
						$id_piece,
						$num_ligne,
						$journal,
						$num_piece,
						$nature,
						$compte,
						$montant_ligne,
						$sens_ligne,
						$libelle_ligne
					);
				if (!$id_ligne)
				{
					dolibarr_print_error($this->db);
				}
				
			}
			/*
			 * TVA -> debit compte tva
			 *
			 */
			$num_ligne++;
			$nature = '';
			$compte = $param->getValeur('COMPTE_TVA_DEDUCTIBLE');
			$sens = 'D';
			$montant_ligne = $facture->total_tva;
			$libelle_ligne = $libelle;
			
			$ligne->nouvelle_ligne(
					$id_piece,
					$num_ligne,
					$journal,
					$num_piece,
					$nature,
					$compte,
					$montant_ligne,
					$sens,
					$libelle_ligne
				);

			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
			/*
			 * Produits/services -> crdit compte fournisseur
			 *
			 */
			$num_ligne++;
			$nature = '';
			$compte = $code_compta;
			$sens = 'C';
			$montant_ligne = $facture->total_ttc;
			$libelle_ligne = $libelle;
			
			$ligne->nouvelle_ligne(
					$id_piece,
					$num_ligne,
					$journal,
					$num_piece,
					$nature,
					$compte,
					$montant_ligne,
					$sens,
					$libelle_ligne
				);
			if ( $ligne < 0)
			{
				dolibarr_print_error($this->db);
			}
		}
	}
}
?>
